@@ -2,10 +2,14 @@ import datetime
 import random
 import os
 
-STORAGE_PATH='/tmp'
-FILENAME_PATTERN='unique_key-%s.list'
+STORAGE_PATH = '/tmp'
+FILENAME_PATTERN = 'unique_key-%s.list'
+NUMERALS = '0123456789abcdefghijklmnopqrstuvwxyz'
+BASE = len(NUMERALS)
+
+def to_base(num, base, numerals=NUMERALS):
+    """Convert <num> to <base> using the symbols in <numerals>"""
 
-def to_base(num, base, numerals='0123456789abcdefghijklmnopqrstuvwxyz'):
     assert int(num)
     assert int(base)
     if len(numerals) < base < 1:
@@ -31,13 +35,16 @@ def to_base(num, base, numerals='0123456789abcdefghijklmnopqrstuvwxyz'):
     return sign + result
 
 def baseNgenerator(base=10, keylength=5, step=1):
-    assert int(base) <= 36
+    """Generate keys of base <base> and length <keylength>"""
+
+    assert int(base) <= BASE
     assert int(keylength) > 0
     while 1:
         yield to_base(random.randrange(base**(keylength-1), base**keylength), base)
 
 def generate_keys(generator, amount=50):
-    generator = baseNgenerator(base=36)
+    """Generate <amount> keys with <generator>"""
+
     keys = set(generator.next() for i in range(amount))
     return tuple(keys)
 
